Jido.Chat.Telegram.StreamOptions (Jido Chat Telegram v1.0.0)

Copy Markdown View Source

Typed options for Telegram stream/3.

Summary

Functions

Builds Telegram draft payload options for sendMessageDraft.

Builds typed stream options from keyword, map, or struct input.

Returns the Zoi schema for stream options.

Builds keyword options for the final send_message/3 call.

Builds transport-level options consumed by ExGramClient.

Types

t()

@type t() :: %Jido.Chat.Telegram.StreamOptions{
  check_params: nil | boolean(),
  debug: nil | boolean(),
  disable_notification: nil | boolean(),
  disable_web_page_preview: nil | boolean(),
  draft_id: nil | integer(),
  entities: nil | any(),
  ex_gram_adapter: nil | any(),
  ex_gram_module: nil | any(),
  link_preview_options: nil | any(),
  parse_mode: nil | binary(),
  reply_markup: nil | any(),
  stream_update_interval_ms: integer(),
  thread_id: nil | any(),
  token: nil | binary(),
  transport: any()
}

Functions

draft_payload_opts(opts, draft_id)

@spec draft_payload_opts(t(), integer()) :: map()

Builds Telegram draft payload options for sendMessageDraft.

new(opts)

Builds typed stream options from keyword, map, or struct input.

schema()

Returns the Zoi schema for stream options.

send_opts(opts)

@spec send_opts(t()) :: keyword()

Builds keyword options for the final send_message/3 call.

transport_opts(opts)

@spec transport_opts(t()) :: keyword()

Builds transport-level options consumed by ExGramClient.