Typed options for Telegram stream/3.
Summary
Functions
Builds Telegram draft payload options for sendMessageDraft.
Builds typed stream options from keyword, map, or struct input.
Returns the Zoi schema for stream options.
Builds keyword options for the final send_message/3 call.
Builds transport-level options consumed by ExGramClient.
Types
@type t() :: %Jido.Chat.Telegram.StreamOptions{ check_params: nil | boolean(), debug: nil | boolean(), disable_notification: nil | boolean(), disable_web_page_preview: nil | boolean(), draft_id: nil | integer(), entities: nil | any(), ex_gram_adapter: nil | any(), ex_gram_module: nil | any(), link_preview_options: nil | any(), parse_mode: nil | binary(), reply_markup: nil | any(), stream_update_interval_ms: integer(), thread_id: nil | any(), token: nil | binary(), transport: any() }
Functions
Builds Telegram draft payload options for sendMessageDraft.
Builds typed stream options from keyword, map, or struct input.
Returns the Zoi schema for stream options.
Builds keyword options for the final send_message/3 call.
Builds transport-level options consumed by ExGramClient.